Subject: 23.2; compile regexp for perl Test.pm "fail #N"

From: Kevin Ryde <[email-masked]>
Date: Wed, 30 Mar 2011 08:19:25 +1100

For the compile.el error regexps, perl's Test.pm can add a "fail #N" if
a given test line is run more than once, in a loop or subr.  The
`perl--Test2' could match that per below.  (Still no good on bzr, so
individual diffs.)

2011-03-29  Kevin Ryde  <[email-masked]>

	* progmodes/compile.el (compilation-error-regexp-alist-alist):
	`perl-Test2' extend to match possible "fail #N" rep count.

2011-03-29  Kevin Ryde  <[email-masked]>

	* compilation.txt (perl-Test2): New samples.

--- compilation.txt.orig	2011-03-30 08:08:25.000000000 +1100
+++ compilation.txt	2011-03-30 08:08:37.000000000 +1100
@@ -496,6 +496,16 @@
 
 # Failed test 1 in foo.t at line 6
 
+* Perl Test.pm module error messages comparing two values
+
+symbol: perl--Test2
+
+# Test 3 got: "99" (d-compilation-perl.t at line 29)
+#   Expected: "88" (my test name)
+#  d-compilation-perl.t line 29 is: ok(99,88,'my test name');
+
+# Test 6 got: "xx" (foo.t at line 33 fail #2)
+#   Expected: "yy"
 
 * Perl Test::Harness output

In GNU Emacs 23.2.1 (i486-pc-linux-gnu, GTK+ Version 2.20.0)
 of 2010-05-16 on raven, modified by Debian
configured using `configure  '--build' 'i486-linux-gnu' '--build' 'i486-linux-gnu' '--prefix=/usr' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib' '--localstatedir=/var/lib' '--infodir=/usr/share/info' '--mandir=/usr/share/man' '--with-pop=yes' '--enable-locallisppath=/etc/emacs23:/etc/emacs:/usr/local/share/emacs/23.2/site-lisp:/usr/local/share/emacs/site-lisp:/usr/share/emacs/23.2/site-lisp:/usr/share/emacs/site-lisp:/usr/share/emacs/23.2/leim' '--with-x=yes' '--with-x-toolkit=gtk' '--with-toolkit-scroll-bars' 'build_alias=i486-linux-gnu' 'CFLAGS=-DDEBIAN -g -O2' 'LDFLAGS=-g' 'CPPFLAGS=''

Important settings:
  value of $LC_ALL: nil
  value of $LC_COLLATE: nil
  value of $LC_CTYPE: nil
  value of $LC_MESSAGES: nil
  value of $LC_MONETARY: nil
  value of $LC_NUMERIC: nil
  value of $LC_TIME: nil
  value of $LANG: en_AU
  value of $XMODIFIERS: nil
  locale-coding-system: iso-latin-1-unix
  default enable-multibyte-characters: t
--- compile.el.orig	2011-03-30 08:08:05.000000000 +1100
+++ compile.el	2011-03-30 08:08:32.000000000 +1100
@@ -381,15 +381,16 @@
      "^# Failed test [0-9]+ in \\([^ \t\r\n]+\\) at line \\([0-9]+\\)"
      1 2)
     (perl--Test2
      ;; Or when comparing got/want values,
      ;; # Test 2 got: "xx" (t-compilation-perl-2.t at line 10)
+     ;; # Test 3 got: "xx" (t-compilation-perl-2.t at line 10 fail #2)
      ;;
      ;; And under Test::Harness they're preceded by progress stuff with
      ;; \r and "NOK",
      ;; ... NOK 1# Test 1 got: "1234" (t/foo.t at line 46)
      ;;
      "^\\(.*NOK.*\\)?# Test [0-9]+ got:.* (\\([^ \t\r\n]+\\) at line \
-\\([0-9]+\\))"
+\\([0-9]+\\)\\( fail #[0-9]+\\)?)"
      2 3)
     (perl--Test::Harness
      ;; perl Test::Harness output, eg.
@@ -381,15 +381,16 @@
      1 2)
     (perl--Test2
-     ;; Or when comparing got/want values,
+     ;; Or when comparing got/want values, with a "fail #n" if repeated
      ;; # Test 2 got: "xx" (t-compilation-perl-2.t at line 10)